/**
 * TiOpenGLAnimatorProxy.m
 * Richard M. Salter
 * Copyright 2011 Logical Labs. All rights reserved
 *
 * Appcelerator Titanium Mobile
 * Copyright (c) 2009-2011 by Appcelerator, Inc. All Rights Reserved.
 * Licensed under the terms of the Apache Public License
 * Please see the LICENSE included with this distribution for details.
 */

#import "ComBadanimationAnimatorProxy.h"
#import "TiUtils.h"

@interface ComBadanimationAnimatorProxy ()
      
@property (nonatomic, retain) CADisplayLink *displayLink;
@property (nonatomic, assign) BOOL animating;

-(void)drawFrame:(CADisplayLink *)sender;
@end

@implementation ComBadanimationAnimatorProxy

@synthesize animating, frameInterval, displayLink;

- (id)init
{
    NSLog(@"animator init");
    self = [super init];
    self.displayLink = nil;
    self.frameInterval = 1;
    self.animating = false;
    return self;
}

- (void)dealloc
{
    [self stopAnimation:nil];
    RELEASE_TO_NIL(displayLink)
    RELEASE_TO_NIL(callback);
    [super dealloc];
}

- (void) setCallback:(KrollCallback *)callback_
{
    hasCallback = [callback_ isKindOfClass:[KrollCallback class]];
    callback = [callback_ retain];
    NSLog(@"in setCallback %@", [callback_ description]);    
}


- (void)startAnimation:(id)args
{
    if (animating) {
        displayLink.paused = NO;
    } else {
        NSLog(@"in animator startAnimation %d", frameInterval);
        CADisplayLink *aDisplayLink = [CADisplayLink displayLinkWithTarget:self selector:@selector(drawFrame:)];
        [aDisplayLink setFrameInterval:frameInterval];
        [aDisplayLink addToRunLoop:[NSRunLoop mainRunLoop] forMode:NSRunLoopCommonModes];
        self.displayLink = aDisplayLink;
        animating = TRUE;
    }
}

- (void)stopAnimation:(id)args
{
    ENSURE_UI_THREAD_0_ARGS
    if (animating)
    {
        [self.displayLink invalidate];
        self.displayLink = nil;
        animating = FALSE;
    }
}

- (void)pauseAnimation:(id)args
{
    ENSURE_UI_THREAD_0_ARGS
    if (animating) self.displayLink.paused = YES;   
}

-(void)drawFrame:(CADisplayLink *)sender
{
    NSDictionary* argDict = [NSDictionary dictionaryWithObjectsAndKeys:[NSNumber numberWithFloat:sender.timestamp], @"timestamp", nil];
    if (hasCallback) {
        [self setValue:callback forUndefinedKey:@"drawFrame"];
        NSLog(@"in animator drawFrame %@ %@", [argDict description], [callback description]);        
        [self fireCallback:@"drawFrame" withArg:argDict withSource:nil];
    }
}




@end
